==> haskell-src-exts-simple-1.23.0.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-simple
version:              1.23.0.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.0.0-lUsBNas4h1PEB7WgIth8
key:                  haskell-src-exts-simple-1.23.0.0-lUsBNas4h1PEB7WgIth8
license:              MIT
copyright:            2016-2020, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  46c6e2cae2d54971b518c2b4574fd913
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-simple-1.23.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-simple-1.23.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.0.0-lUsBNas4h1PEB7WgIth8
depends:
    base-4.16.4.0 haskell-src-exts-1.23.1-1wKlAKue04bAAc2kpPdhfF

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-simple-1.23.0.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-simple
version:              1.23.0.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.0.0-880iaxQUVV0InWKdalrOim
key:                  haskell-src-exts-simple-1.23.0.0-880iaxQUVV0InWKdalrOim
license:              MIT
copyright:            2016-2020, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  f4c477f79530b6a85a2ad1496b22e1a2
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-simple-1.23.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-simple-1.23.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.0.0-880iaxQUVV0InWKdalrOim
depends:
    base-4.16.4.0 haskell-src-exts-1.23.1-IWcuqDdKAvs8pCAXKqJccv

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
